Enum robots::actors::actor_ref::ActorPath
[−]
[src]
pub enum ActorPath {
Local(String),
Distant(ConnectionInfo),
}Path to an actor.
This enum contains the information for actors whether they are local or distant.
Variants
Local(String)Logical path to a local actor.
Distant(ConnectionInfo)Logical path and connection information for a distant actor.
Methods
impl ActorPath[src]
fn new_local(path: String) -> Arc<ActorPath>[src]
Creates a new local ActorPath variant with the given logical_path.
fn new_distant(
distant_logical_path: String,
addr_port: String
) -> Arc<ActorPath>[src]
distant_logical_path: String,
addr_port: String
) -> Arc<ActorPath>
Creates a new distant ActorPath.
fn logical_path(&self) -> &String[src]
Gives a reference to the logical path of an actor.
Note that this gives the local logical path whether the actor is local or not.
fn child(&self, name: String) -> Arc<ActorPath>[src]
Creates an ActorPath for a child of an actor.
This gives a Local variant, because actors are always created locally.