Struct robots::actors::actor_ref::ConnectionInfo
[−]
[src]
pub struct ConnectionInfo { /* fields omitted */ }This gives connection informations on how to get to the distant actors.
- The distant_logical_path is something like "/user/distant/actor".
- The addr_port is something like "127.0.0.1:12345"
Note that the storage of the addr_port could be improved, but is not a concern for now.
Methods
impl ConnectionInfo[src]
fn distant_logical_path(&self) -> &String[src]
Distant logical path.
fn addr_port(&self) -> &String[src]
Address and port of the distant actor.